package fr.yunes.search;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class FileSplitter {
    private FileSplitter() {}
    public static List<Chunk> getChunks(String fn,int n) throws IOException {
        if (n>100) n = 100;
        File f = new File(fn);
        if (!f.exists() || !f.isFile() || !f.canRead()) throw new IOException("Problem with "+fn);
        long size = f.length();
        List<Chunk> l = new ArrayList<>();
        FileInputStream is = new FileInputStream(f);
        long start = 0;
        long chunkSize = size/n;
        for (int i=0; i<n; i++) {
            long stop = is.skip(chunkSize)+start;
            int c;
            boolean next = false;
            loop:
            while ( (c=is.read()) != -1) {
                stop++;
                switch (c) {
                    case 0x0d:
                        next = true;
                        break;
                    case 0x0a:
                        break loop;
                    default:
                        if (next) {
                            stop--;
                            break loop;
                        }
                        next = false;
                        break;
                }
            }
//            System.out.printf("Stopped at %02x\n",c);
            if (i==n-1) stop = size;
            l.add(new Chunk(start,stop));
            start = stop;
        }
        is.close();
        return l;
    }
}
